@@ -48,7 +48,7 @@ impl Core {
 
     pub(crate) async fn relocated(&self, new_node: Node, new_section: Section) -> Self {
         Self::new(
-            self.comm.async_clone().await,
+            self.comm.clone(),
             new_node,
             new_section,
             None,
@@ -216,7 +216,7 @@ impl Core {
         let dst_pk = self.section_key_by_name(&target_name);
         wire_msg.set_dst_section_pk(dst_pk);
 
-        let command = Command::SendMessage {
+        let command = Command::SendMessageDeliveryGroup {
             recipients: targets,
             delivery_group_size: dg_size,
             wire_msg,
